@@ -7,7 +7,7 @@ from datetime import datetime
 from collections import defaultdict
 Tree= lambda: defaultdict(Tree)
 
-def medpc_read (file, rat_id=None, save=True, override = True, replace = True, log=''):
+def medpc_read (file, working_var_label='', rat_id=None, save=True, override = True, replace = True, log=''):
     '''
     Inputs:
     1. file (str, path)
@@ -75,16 +75,17 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                         if 'DIM' in line:
                             pat = re.compile(r'(DIM\s+)(\w)([\s=\d]*)([\s\\]*)(\w*\s*\w*)(\s+)([\w\(\)]*)')
                             var, name = pat.search(line).group(2), pat.search(line).group(5)
-                            if var != 'A':
+                            if var != working_var_label: #'A'
                                 if name != '':
                                     name = re.sub('[\s]*', '', name)
                                     TS_var_name_map[var] = "(%s)"%var+name
                                     TS_var_name_maps[programname] = TS_var_name_map
-                        elif re.match(r'\s+\\\sA\(\d*\)', line):
-                            pat = re.compile(r'(\s+\\\s)(A\()(\d*)(\))\W*([\w\s\(\)]*)([\w\s\(\),\/]*)')
-                            idx, name = pat.search(line).group(3), pat.search(line).group(5)
-                            arrayA_name_map[idx]='A(%s)'%idx+name.strip('\n')
-                            arrayA_name_maps[programname] = arrayA_name_map
+                        elif working_var_label != '':
+                            if re.match(r'\s+\\\s%s\(\d*\)'%working_var_label, line):
+                                pat = re.compile(r'(\s+\\\s)(A\()(\d*)(\))\W*([\w\s\(\)]*)([\w\s\(\),\/]*)')
+                                idx, name = pat.search(line).group(3), pat.search(line).group(5)
+                                arrayA_name_map[idx]='%s(%s)'%(working_var_label,idx)+name.strip('\n')
+                                arrayA_name_maps[programname] = arrayA_name_map
             
             except:
                 log += nowtime+'>>\t'+'Error!Pleas provide MSN programe in the data folder: %s'%MSN +'\n'
@@ -137,27 +138,30 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
     ####################################
     # Get values for working variables
     ####################################
-    workingVar_tree = Tree() #computed, but not return for this version
-    for program_nm in progamnames:
-        for d, alldata_dict in alldata_tree[program_nm].items():
-            temp2_dfs = [] # for working vars dataframe
-            for rat, data_d in alldata_dict.items():
-                temp2 = {}
-                for k, nm in arrayA_name_maps[program_nm].items():
-                    try:
-                        temp2[nm] = data_d['A'].iloc[int(k)]
-                    except IndexError:
-                        log += nowtime+'>>\t'+'Error!%s in MSN (%s) cannnot find in file %s'%(nm,programname,file) + '\n'
-                        temp2[nm] = np.nan
-                temp2_df = pd.DataFrame.from_dict(temp2, orient = 'index', columns = [rat])
-                temp2_dfs.append(temp2_df)
-                temp2_dfs_concat = pd.concat(temp2_dfs, axis = 1)
-            workingVar_tree[d][program_nm] = temp2_dfs_concat
-    
-    workingVar_dfs = {}
-    for d, v in workingVar_tree.items():
-        workingVar_dfs[d] =  pd.concat(v.values(), axis = 1, join = 'outer')
-        workingVar_dfs[d].sort_index(ascending=True, axis=1, inplace = True)
+    if working_var_label != '':
+        workingVar_tree = Tree() #computed, but not return for this version
+        for program_nm in progamnames:
+            for d, alldata_dict in alldata_tree[program_nm].items():
+                temp2_dfs = [] # for working vars dataframe
+                for rat, data_d in alldata_dict.items():
+                    temp2 = {}
+                    for k, nm in arrayA_name_maps[program_nm].items():
+                        try:
+                            temp2[nm] = data_d['A'].iloc[int(k)]
+                        except IndexError:
+                            log += nowtime+'>>\t'+'Error!%s in MSN (%s) cannnot find in file %s'%(nm,programname,file) + '\n'
+                            temp2[nm] = np.nan
+                    temp2_df = pd.DataFrame.from_dict(temp2, orient = 'index', columns = [rat])
+                    temp2_dfs.append(temp2_df)
+                    temp2_dfs_concat = pd.concat(temp2_dfs, axis = 1)
+                workingVar_tree[d][program_nm] = temp2_dfs_concat
+        
+        workingVar_dfs = {}
+        for d, v in workingVar_tree.items():
+            workingVar_dfs[d] =  pd.concat(v.values(), axis = 1, join = 'outer')
+            workingVar_dfs[d].sort_index(ascending=True, axis=1, inplace = True)
+    else:
+        workingVar_dfs = {}
     
     ######################################
     # Save data into local files
@@ -176,7 +180,8 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                 if override:
                     with pd.ExcelWriter(filename, mode = 'r', engine='openpyxl') as writer: # pylint: disable=abstract-class-instantiated
                         MSN_dict[d].to_excel(writer,sheet_name='MSNs',index=False)
-                        workingVar_dfs[d].to_excel(writer, sheet_name='Summary_(A)', index = True)
+                        if working_var_label !='':
+                            workingVar_dfs[d].to_excel(writer, sheet_name='Summary_(%s)'%working_var_label, index = True)
                         for sheet, df in TS_df_dict.items():
                             df.to_excel(writer, sheet_name = sheet, index=False)
                         log += nowtime+'>>\t'+'Override the exisitng local excel file %s'%filename +'\n'
@@ -191,21 +196,22 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                             writer.book = book
                             MSNs_file = pd.read_excel(filename,sheet_name = 'MSNs')
                             MSNs_file['ID'] = MSNs_file['ID'].astype('str')
-                            summary_file = pd.read_excel(filename, sheet_name = 'Summary_(A)')
-                            summary_file.set_index('Unnamed: 0', inplace = True)
-                            summary_file.columns = summary_file.columns.astype(str)
+                            if working_var_label !='':
+                                summary_file = pd.read_excel(filename, sheet_name = 'Summary_(%s)'%working_var_label)
+                                summary_file.set_index('Unnamed: 0', inplace = True)
+                                summary_file.columns = summary_file.columns.astype(str)
                             
                             new = list(set(TS_df_dict.keys())^set(x1.sheet_names))
-                            new = [n for n in new if n!= 'Summary_(A)' and n!= 'MSNs']
+                            new = [n for n in new if n!= 'Summary_(%s)'%working_var_label and n!= 'MSNs']
                             if len(new)>0: # determine if this is partial overlap, if yes, only replace the overlapped part, keep the other original data and append new data.
                             
                                 new_MSNs_file = pd.concat([MSN_dict[d], MSNs_file[MSNs_file['ID'].isin(new)]], axis = 0) # Concat new MSNs info with old one, which doesn't contain the overlapped ID
-        
-                                working_new_col = list(workingVar_dfs[d].columns[workingVar_dfs[d].columns.isin(new)])
-                                new_col = list(summary_file.columns[summary_file.columns.isin(new)])
-                                
-                                new_summary_file = pd.concat([workingVar_dfs[d][overlap], workingVar_dfs[d][working_new_col], summary_file[new_col]], axis = 1)
                                 
+                                if working_var_label !='':
+                                    working_new_col = list(workingVar_dfs[d].columns[workingVar_dfs[d].columns.isin(new)])
+                                    new_col = list(summary_file.columns[summary_file.columns.isin(new)])
+                                    new_summary_file = pd.concat([workingVar_dfs[d][overlap], workingVar_dfs[d][working_new_col], summary_file[new_col]], axis = 1)
+                                    
                                 new_TS_df_dict = TS_df_dict.copy()
                                 new_in_excel  = list(set(x1.sheet_names) & set(new))
                                 for new_id in new_in_excel:
@@ -213,7 +219,8 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                             
                             else: # if this is a complete overlap. Then directly replace everything
                                 new_MSNs_file = MSN_dict[d].copy()
-                                new_summary_file = workingVar_dfs[d].copy()
+                                if working_var_label !='':
+                                    new_summary_file = workingVar_dfs[d].copy()
                                 new_TS_df_dict = TS_df_dict.copy()
                             
                             new_MSNs_file.sort_values(by = ['ID']) # sort ID from small to largest
@@ -221,7 +228,8 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                             
                             with pd.ExcelWriter(filename, mode = 'r', engine='openpyxl') as writer: # pylint: disable=abstract-class-instantiated
                                 new_MSNs_file.to_excel(writer, sheet_name = 'MSNs', index = False)
-                                new_summary_file.to_excel(writer, sheet_name = 'Summary_(A)', index = True)
+                                if working_var_label !='':
+                                    new_summary_file.to_excel(writer, sheet_name = 'Summary_(%s)'%working_var_label, index = True)
                                 for sheet, df in new_TS_df_dict.items():
                                     df.to_excel(writer, sheet_name = sheet, index=False)
                                 log += nowtime+'>>\t'+'Replace overlapped MED-PC data in the existing local excel file %s'%filename +'\n'
@@ -237,17 +245,18 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                             else:    
                                 MSN_same = False
                             
-                            summary_file = pd.read_excel(filename, sheet_name = 'Summary_(A)')
-                            if summary_file.values.shape == workingVar_dfs[d].values.shape:
-                                if np.prod(np.equal(summary_file.astype(str).values, workingVar_dfs[d].atype(str).values)):
-                                    if list(summary_file.columns) == list(workingVar_dfs[d].columns):
-                                        summary_same = True
+                            if working_var_label !='':
+                                summary_file = pd.read_excel(filename, sheet_name = 'Summary_(%s)'%working_var_label)
+                                if summary_file.values.shape == workingVar_dfs[d].values.shape:
+                                    if np.prod(np.equal(summary_file.astype(str).values, workingVar_dfs[d].atype(str).values)):
+                                        if list(summary_file.columns) == list(workingVar_dfs[d].columns):
+                                            summary_same = True
+                                        else:
+                                            summary_same = False
                                     else:
                                         summary_same = False
                                 else:
                                     summary_same = False
-                            else:
-                                summary_same = False
                                 
                             if not MSN_same or not summary_same: #if two MSNs summary are not the same append current one to the file one
                                 book = load_workbook(filename)
@@ -258,16 +267,17 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                                     writer.sheets = {ws.title: ws for ws in book.worksheets if ws.title=='MSNs'} #get MSNs sheet from existing excel
                                     MSN_dict[d].to_excel(writer, sheet_name = 'MSNs', startrow = writer.sheets['MSNs'].max_row, header = None, index= False)
                                 
-                                if not summary_same:
-                                    # creat a new file and replace the old one
-                                    std= book['Summary_(A)']
-                                    book.remove(std)
-                                    summary_file.set_index('Unnamed: 0', inplace = True)
-                                    newfile = pd.concat([summary_file, workingVar_dfs[d]], axis = 1, join = 'outer')
-                                    newfile.to_excel(writer, sheet_name = 'Summary_(A)', index = True)
+                                if working_var_label !='':
+                                    if not summary_same:
+                                        # creat a new file and replace the old one
+                                        std= book['Summary_(%s)'%working_var_label]
+                                        book.remove(std)
+                                        summary_file.set_index('Unnamed: 0', inplace = True)
+                                        newfile = pd.concat([summary_file, workingVar_dfs[d]], axis = 1, join = 'outer')
+                                        newfile.to_excel(writer, sheet_name = 'Summary_(%s)'%working_var_label, index = True) 
+                                    writer.save()
+                                    writer.close()
                                     
-                                writer.save()
-                                writer.close()
                             with pd.ExcelWriter(filename, mode = 'a', engine='openpyxl') as writer: # pylint: disable=abstract-class-instantiated
                                 for sheet in new:
                                     TS_df_dict[sheet].to_excel(writer, sheet_name = sheet, index=False) 
@@ -287,17 +297,18 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                             else:    
                                 MSN_same = False
                             
-                            summary_file = pd.read_excel(filename, sheet_name = 'Summary_(A)')
-                            if summary_file.values.shape == workingVar_dfs[d].values.shape:
-                                if np.prod(np.equal(summary_file.astype(str).values, workingVar_dfs[d].astype(str).values)):
-                                    if list(summary_file.columns) == list(workingVar_dfs[d].columns):
-                                        summary_same = True
+                            if working_var_label !='':
+                                summary_file = pd.read_excel(filename, sheet_name = 'Summary_(%s)'%working_var_label)
+                                if summary_file.values.shape == workingVar_dfs[d].values.shape:
+                                    if np.prod(np.equal(summary_file.astype(str).values, workingVar_dfs[d].astype(str).values)):
+                                        if list(summary_file.columns) == list(workingVar_dfs[d].columns):
+                                            summary_same = True
+                                        else:
+                                            summary_same = False
                                     else:
                                         summary_same = False
                                 else:
                                     summary_same = False
-                            else:
-                                summary_same = False
                                 
                             if not MSN_same or not summary_same: #if two MSNs summary are not the same append current one to the file one
                                 book = load_workbook(filename)
@@ -308,16 +319,17 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
                                     writer.sheets = {ws.title: ws for ws in book.worksheets if ws.title=='MSNs'} #get MSNs sheet from existing excel
                                     MSN_dict[d].to_excel(writer, sheet_name = 'MSNs', startrow = writer.sheets['MSNs'].max_row, header = None, index= False)
                                 
-                                if not summary_same:
-                                    # creat a new file and replace the old one
-                                    std= book['Summary_(A)']
-                                    book.remove(std)
-                                    summary_file.set_index('Unnamed: 0', inplace = True)
-                                    newfile = pd.concat([summary_file, workingVar_dfs[d]], axis = 1, join = 'outer')
-                                    newfile.to_excel(writer, sheet_name = 'Summary_(A)', index = True)
+                                if working_var_label !='':
+                                    if not summary_same:
+                                        # creat a new file and replace the old one
+                                        std= book['Summary_(%s)'%working_var_label]
+                                        book.remove(std)
+                                        summary_file.set_index('Unnamed: 0', inplace = True)
+                                        newfile = pd.concat([summary_file, workingVar_dfs[d]], axis = 1, join = 'outer')
+                                        newfile.to_excel(writer, sheet_name = 'Summary_(%s)'%working_var_label, index = True)
+                                    writer.save()
+                                    writer.close()
                                     
-                                writer.save()
-                                writer.close()
                             with pd.ExcelWriter(filename, mode = 'a', engine='openpyxl') as writer: # pylint: disable=abstract-class-instantiated
                                 for sheet in new:
                                     TS_df_dict[sheet].to_excel(writer, sheet_name = sheet, index=False) 
@@ -326,9 +338,10 @@ def medpc_read (file, rat_id=None, save=True, override = True, replace = True, l
             else: # file doesn't exist
                 with pd.ExcelWriter(filename, engine='openpyxl') as writer: # pylint: disable=abstract-class-instantiated
                     MSN_dict[d].to_excel(writer,sheet_name='MSNs',index=False)
-                    workingVar_dfs[d].to_excel(writer, sheet_name='Summary_(A)', index = True)
+                    if working_var_label !='':
+                        workingVar_dfs[d].to_excel(writer, sheet_name='Summary_(%s)'%working_var_label, index = True)
                     for sheet, df in TS_df_dict.items():
                         df.to_excel(writer, sheet_name = sheet, index=False)
                     log += nowtime+'>>\t'+'Extract MED-PC data file to a new local excel file %s'%file_path+'\n'
 
-    return TS_df_tree, log
+    return TS_df_tree, log
\ No newline at end of file
